summaryrefslogtreecommitdiff
path: root/lib/x509/sign.c
diff options
context:
space:
mode:
authorLeonardo Bras <leobras.c@gmail.com>2021-05-21 03:11:29 -0300
committerLeonardo Bras <leobras.c@gmail.com>2021-05-21 03:13:39 -0300
commitcee6093e8c16f2e1869812b7a69e4c13f9b5aa67 (patch)
treedd6cf2ebbb4a5a9ab21416facc3c0fa15a45218b /lib/x509/sign.c
parentdf640cf6670848b7af967b3673b3807ad491b4be (diff)
downloadgnutls-cee6093e8c16f2e1869812b7a69e4c13f9b5aa67.tar.gz
ASN1 : Remove warnings related to old libtasn1 namings
While compiling gnutls, some warnings related to deprecated names can be printed, such as: ./../x509/x509_int.h:392:13: warning: 'ASN1_TYPE' macro is deprecated, use 'asn1_node' instead. 392 | int _gnutls_x509_write_key_int_le(ASN1_TYPE node, const char *value, | ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ To avoid that, rename types as show in devel/libtasn1/NEWS (release 3.1): ASN1_DATA_NODE -> asn1_data_node_st ASN1_ARRAY_TYPE -> asn1_static_node (was asn1_static_node_t) ASN1_TYPE -> asn1_node ASN1_TYPE_EMPTY -> NULL static_struct_asn -> asn1_static_node_st node_asn_struct -> asn1_node_st node_asn -> asn1_node_st Signed-off-by: Leonardo Bras <leobras.c@gmail.com>
Diffstat (limited to 'lib/x509/sign.c')
-rw-r--r--lib/x509/sign.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/x509/sign.c b/lib/x509/sign.c
index 461524f5bf..303e9f2f91 100644
--- a/lib/x509/sign.c
+++ b/lib/x509/sign.c
@@ -39,11 +39,11 @@
#include <pk.h>
/* This is the same as the _gnutls_x509_sign, but this one will decode
* the ASN1_TYPE given, and sign the DER data. Actually used to get the DER
* of the TBS and sign it on the fly.
*/
int
-_gnutls_x509_get_tbs(ASN1_TYPE cert, const char *tbs_name,
+_gnutls_x509_get_tbs(asn1_node cert, const char *tbs_name,
gnutls_datum_t * tbs)
{
return _gnutls_x509_der_encode(cert, tbs_name, tbs, 0);
@@ -88,7 +88,7 @@ _gnutls_x509_crt_get_spki_params(gnutls_x509_crt_t crt,
/*-
* _gnutls_x509_pkix_sign - This function will sign a CRL or a certificate with a key
* @src: should contain an ASN1_TYPE
* @issuer: is the certificate of the certificate issuer
* @issuer_key: holds the issuer's private key
*
@@ -99,7 +99,7 @@ _gnutls_x509_crt_get_spki_params(gnutls_x509_crt_t crt,
* negative error value.
-*/
int
-_gnutls_x509_pkix_sign(ASN1_TYPE src, const char *src_name,
+_gnutls_x509_pkix_sign(asn1_node src, const char *src_name,
gnutls_digest_algorithm_t dig,
unsigned int flags,
gnutls_x509_crt_t issuer,
@@ -39,11 +39,11 @@
#include <pk.h>
/* This is the same as the _gnutls_x509_sign, but this one will decode
- * the ASN1_TYPE given, and sign the DER data. Actually used to get the DER
+ * the asn1_node given, and sign the DER data. Actually used to get the DER
* of the TBS and sign it on the fly.
*/
@@ -88,7 +88,7 @@ _gnutls_x509_crt_get_spki_params(gnutls_x509_crt_t crt,
/*-
* _gnutls_x509_pkix_sign - This function will sign a CRL or a certificate with a key
- * @src: should contain an ASN1_TYPE
+ * @src: should contain an asn1_node
* @issuer: is the certificate of the certificate issuer
* @issuer_key: holds the issuer's private key